@@ -9,6 +9,6 @@ test_that("test_replyr_split.R", {
     order = c(.1, .2, .3, .4, .5),
     values = c(10, 20, 2, 4, 8)
   )
-  d %>% replyr_split('group')
+  replyr_split(d, 'group')
 
 })
